﻿# api: multitool
# version: 0.1
# title: Get groups of user
# description: extract .MemberOf list
# type: inline
# category: bulk
# icon: user
# vars:
#    { name: usernames, type: text, value="$username", description: User/users to compile membership list from }
# hidden: 0
# status: beta
# config: -
#
# Get group membership for list of users
#
#  ❏ `username` from standard field
#  ❏ comma-separated list of AD groups in `groups` field
#


Param(
    $usernames = (Read-Host "Usernames")
);

$usernames = $usernames -split "[;,\s]+" | ? { $_ -match "\w+" } | % { $_ -replace "\w+\\","" } | ? { Get-ADUser $_ }
$groups = $usernames | % { (Get-ADUser $_ -Prop MemberOf).MemberOf }
$groups = $groups -notmatch "Allowed RODC Password Replication Group"
$groups = $groups | % { "$_" -replace "^CN=|,OU=.+$","" }  | Sort -Unique | % { "$_;" }
$groups | FL | Out-String | Write-Host
